==> CGI-Auth-FOAF_SSL-1.002.tar.gz: CGI-Auth-FOAF_SSL-1.002/examples/testing.pl <==
use CGI::Auth::FOAF_SSL;
use Data::Printer;

my $cert = '-----BEGIN CERTIFICATE-----
MIIDwjCCAyugAwIBAgIBADANBgkqhkiG9w0BAQUFADCBiDELMAkGA1UEBhMCR0Ix
FDASBgNVBAgTC0Vhc3QgU3Vzc2V4MQ4wDAYDVQQHEwVMZXdlczEVMBMGA1UEChMM
VG9ieSBJbmtzdGVyMRUwEwYDVQQDEwxUb2J5IElua3N0ZXIxJTAjBgkqhkiG9w0B
CQEWFm1haWxAdG9ieWlua3N0ZXIuY28udWswHhcNMDkwNjIyMTE0OTQ1WhcNMTMw
NjIxMTE0OTQ1WjCBiDELMAkGA1UEBhMCR0IxFDASBgNVBAgTC0Vhc3QgU3Vzc2V4
MQ4wDAYDVQQHEwVMZXdlczEVMBMGA1UEChMMVG9ieSBJbmtzdGVyMRUwEwYDVQQD
EwxUb2J5IElua3N0ZXIxJTAjBgkqhkiG9w0BCQEWFm1haWxAdG9ieWlua3N0ZXIu
Y28udWswgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBANCO9ePkHf7wd12IV4pk
dWb6sMiaYwVe5epncwwARrxIoRfkwXrBkvV+bE9jjTQDODYNeLIPinnZEAfeIPEs
ahvFw88wA8gUEc0bjhH9BjlwJiWq9SzcGSm70CB11mkkBDkMfy2N/Jj6UeD3eWi4
7tCB23gcyHRcLzG/rJ2WD8lPAgMBAAGjggE4MIIBNDAdBgNVHQ4EFgQUsCURLq94
EfloWTu8vHlc/1qRWMAwgbUGA1UdIwSBrTCBqoAUsCURLq94EfloWTu8vHlc/1qR
WMChgY6kgYswgYgxCzAJBgNVBAYTAkdCMRQwEgYDVQQIEwtFYXN0IFN1c3NleDEO
MAwGA1UEBxMFTGV3ZXMxFTATBgNVBAoTDFRvYnkgSW5rc3RlcjEVMBMGA1UEAxMM
VG9ieSBJbmtzdGVyMSUwIwYJKoZIhvcNAQkBFhZtYWlsQHRvYnlpbmtzdGVyLmNv
LnVrggEAMAwGA1UdEwQFMAMBAf8wTQYDVR0RBEYwRIEWbWFpbEB0b2J5aW5rc3Rl
ci5jby51a4ENdGFpQGc1bi5jby51a4YbaHR0cDovL3RvYnlpbmtzdGVyLmNvLnVr
LyNpMA0GCSqGSIb3DQEBBQUAA4GBADrTzhHHsx2kox2rl1LLQvr7lCL0QJYoC/5B
NwTOr2DmtRsMbGLJsBoXylOmcBmKt6jwEjt8ZtpordY5WuCHdhQnQMPHVq7QedFN
67BP9knqFu7LV9dmqn12k0/I4b34/A0erLHTVzlj/E91OkASTf3M1ipGMcC8H97C
xQX4IrD3
-----END CERTIFICATE-----';

my $bblfish = '-----BEGIN CERTIFICATE-----
MIICxzCCAjCgAwIBAgIGAScyueb/MA0GCSqGSIb3DQEBBQUAMFgxCzAJBgNVBAYT
AlVTMRcwFQYDVQQKDA5GT0FGIENlcnRzIEluYzEWMBQGA1UECwwNMTI2Nzg2NjM5
NjM1NDEYMBYGA1UEAwwPSGVucnkgKGJibGZpc2gpMB4XDTEwMDMwNjA5MDYzNloX
DTExMDIyNTA5MDYzNlowWDELMAkGA1UEBhMCVVMxFzAVBgNVBAoMDkZPQUYgQ2Vy
dHMgSW5jMRYwFAYDVQQLDA0xMjY3ODY2Mzk2MzU0MRgwFgYDVQQDDA9IZW5yeSAo
YmJsZmlzaCkwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAJ15v+L0mLx5batz
4os5TbUmaEnucYcGMsmfP5Tly021EjUTaWCBWHlm83kgkWo/Qlr2VEKIsukZSnmH
LmJELXwGePj9UpJtzdbzKGsf28vT8gg0cqISda7RCRfQiEwEjgTlv9FBZNH3iW2L
svJGwFaHjbh8xv7pYYgIYd3juLVHAgMBAAGjgZswgZgwDwYDVR0TAQH/BAUwAwEB
/zAOBgNVHQ8BAf8EBAMCAuwwEQYJYIZIAYb4QgEBBAQDAgWgMB0GA1UdDgQWBBT/
580MeLignVmAupmA06p1AxfNRjAfBgNVHSMEGDAWgBT/580MeLignVmAupmA06p1
AxfNRjAiBgNVHREEGzAZhhdodHRwOi8vYmJsZmlzaC5uZXQvI2hqczANBgkqhkiG
9w0BAQUFAAOBgQADheTaG7AIFjAfvTmEp9P8jGjKj+FLlNY1vUuIv2FEBOfUF4b+
FvlJP02Aoj+TfwWQzZrKuDMveeyZrucSsH+kUKQklhM4qCtilR9qGh6DEc3kWkN+
DLmcf0RI0RtEUaXDLwTf7jtnlDWs41so0Bu8FEAuDvCTvTdOTBGqEhAvVA==
-----END CERTIFICATE-----';

my $auth = CGI::Auth::FOAF_SSL->new($cert);
p $auth;

#print $auth->account->identity . "\n";
#print $auth->account->name . "\n";
#print $auth->account->homepage . "\n";

print $auth->agent->identity . "\n";
print $auth->agent->name . "\n";
print $auth->agent->homepage . "\n";
print $auth->agent->img . "\n";
print $auth->agent->mbox . "\n";

print ($auth->is_secure ? 'Secure' : 'NOT SECURE');
print "\n";

==> CGI-Auth-FOAF_SSL-1.003.tar.gz: CGI-Auth-FOAF_SSL-1.003/examples/testing.pl <==
use CGI::Auth::FOAF_SSL;
use Data::Printer;

my $cert = '-----BEGIN CERTIFICATE-----
MIIDwjCCAyugAwIBAgIBADANBgkqhkiG9w0BAQUFADCBiDELMAkGA1UEBhMCR0Ix
FDASBgNVBAgTC0Vhc3QgU3Vzc2V4MQ4wDAYDVQQHEwVMZXdlczEVMBMGA1UEChMM
VG9ieSBJbmtzdGVyMRUwEwYDVQQDEwxUb2J5IElua3N0ZXIxJTAjBgkqhkiG9w0B
CQEWFm1haWxAdG9ieWlua3N0ZXIuY28udWswHhcNMDkwNjIyMTE0OTQ1WhcNMTMw
NjIxMTE0OTQ1WjCBiDELMAkGA1UEBhMCR0IxFDASBgNVBAgTC0Vhc3QgU3Vzc2V4
MQ4wDAYDVQQHEwVMZXdlczEVMBMGA1UEChMMVG9ieSBJbmtzdGVyMRUwEwYDVQQD
EwxUb2J5IElua3N0ZXIxJTAjBgkqhkiG9w0BCQEWFm1haWxAdG9ieWlua3N0ZXIu
Y28udWswgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBANCO9ePkHf7wd12IV4pk
dWb6sMiaYwVe5epncwwARrxIoRfkwXrBkvV+bE9jjTQDODYNeLIPinnZEAfeIPEs
ahvFw88wA8gUEc0bjhH9BjlwJiWq9SzcGSm70CB11mkkBDkMfy2N/Jj6UeD3eWi4
7tCB23gcyHRcLzG/rJ2WD8lPAgMBAAGjggE4MIIBNDAdBgNVHQ4EFgQUsCURLq94
EfloWTu8vHlc/1qRWMAwgbUGA1UdIwSBrTCBqoAUsCURLq94EfloWTu8vHlc/1qR
WMChgY6kgYswgYgxCzAJBgNVBAYTAkdCMRQwEgYDVQQIEwtFYXN0IFN1c3NleDEO
MAwGA1UEBxMFTGV3ZXMxFTATBgNVBAoTDFRvYnkgSW5rc3RlcjEVMBMGA1UEAxMM
VG9ieSBJbmtzdGVyMSUwIwYJKoZIhvcNAQkBFhZtYWlsQHRvYnlpbmtzdGVyLmNv
LnVrggEAMAwGA1UdEwQFMAMBAf8wTQYDVR0RBEYwRIEWbWFpbEB0b2J5aW5rc3Rl
ci5jby51a4ENdGFpQGc1bi5jby51a4YbaHR0cDovL3RvYnlpbmtzdGVyLmNvLnVr
LyNpMA0GCSqGSIb3DQEBBQUAA4GBADrTzhHHsx2kox2rl1LLQvr7lCL0QJYoC/5B
NwTOr2DmtRsMbGLJsBoXylOmcBmKt6jwEjt8ZtpordY5WuCHdhQnQMPHVq7QedFN
67BP9knqFu7LV9dmqn12k0/I4b34/A0erLHTVzlj/E91OkASTf3M1ipGMcC8H97C
xQX4IrD3
-----END CERTIFICATE-----';

my $bblfish = '-----BEGIN CERTIFICATE-----
MIICxzCCAjCgAwIBAgIGAScyueb/MA0GCSqGSIb3DQEBBQUAMFgxCzAJBgNVBAYT
AlVTMRcwFQYDVQQKDA5GT0FGIENlcnRzIEluYzEWMBQGA1UECwwNMTI2Nzg2NjM5
NjM1NDEYMBYGA1UEAwwPSGVucnkgKGJibGZpc2gpMB4XDTEwMDMwNjA5MDYzNloX
DTExMDIyNTA5MDYzNlowWDELMAkGA1UEBhMCVVMxFzAVBgNVBAoMDkZPQUYgQ2Vy
dHMgSW5jMRYwFAYDVQQLDA0xMjY3ODY2Mzk2MzU0MRgwFgYDVQQDDA9IZW5yeSAo
YmJsZmlzaCkwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAJ15v+L0mLx5batz
4os5TbUmaEnucYcGMsmfP5Tly021EjUTaWCBWHlm83kgkWo/Qlr2VEKIsukZSnmH
LmJELXwGePj9UpJtzdbzKGsf28vT8gg0cqISda7RCRfQiEwEjgTlv9FBZNH3iW2L
svJGwFaHjbh8xv7pYYgIYd3juLVHAgMBAAGjgZswgZgwDwYDVR0TAQH/BAUwAwEB
/zAOBgNVHQ8BAf8EBAMCAuwwEQYJYIZIAYb4QgEBBAQDAgWgMB0GA1UdDgQWBBT/
580MeLignVmAupmA06p1AxfNRjAfBgNVHSMEGDAWgBT/580MeLignVmAupmA06p1
AxfNRjAiBgNVHREEGzAZhhdodHRwOi8vYmJsZmlzaC5uZXQvI2hqczANBgkqhkiG
9w0BAQUFAAOBgQADheTaG7AIFjAfvTmEp9P8jGjKj+FLlNY1vUuIv2FEBOfUF4b+
FvlJP02Aoj+TfwWQzZrKuDMveeyZrucSsH+kUKQklhM4qCtilR9qGh6DEc3kWkN+
DLmcf0RI0RtEUaXDLwTf7jtnlDWs41so0Bu8FEAuDvCTvTdOTBGqEhAvVA==
-----END CERTIFICATE-----';

my $foaf_ssl_webid = '-----BEGIN CERTIFICATE-----
MIIDWzCCAsSgAwIBAgIJAPWKstF2BhSOMA0GCSqGSIb3DQEBBQUAMG0xCzAJBgNV
BAYTAkZSMRAwDgYDVQQIEwdFc3Nvbm5lMRYwFAYDVQQKEw13ZWJpZC5mY25zLmV1
MRYwFAYDVQQDEw13ZWJpZC5mY25zLmV1MRwwGgYJKoZIhvcNAQkBFg13ZWJpZEBm
Y25zLmV1MB4XDTEyMDMyNjE3MDE0OFoXDTEzMDMyNjE3MDE0OFowKjEoMCYGA1UE
AxQfQ0dJOjpBdXRoOjpGT0FGX19TU0wgdGVzdCBXZWJJRDCCASIwDQYJKoZIhvcN
AQEBBQADggEPADCCAQoCggEBANGm37aQgbqPbUqTAYGHyexDPEK4U3lGbI0ItBsg
QMDp2E/BRnbr+yKN8IMQy/LUExXTLJaiUBYJKgT2UI/cy8HZ/U4mgDDbptC5Nfe2
De9WEZ57+glWwZqdrlsxU80TpUnzXgtrJ+xNvgWMRNO+fW2bLA3dyP9SQ6sC1bEE
NVHyfYjb/mURfQPmlh2hg9xdLNXx4gMXM/wQ3FGJpz4SaS9wyTYnBqOHS/f5pfCl
3qa2WYy1BmGgundcGBI7d3IS7Bbuh0zo6/FVzeZdiDmnCbYGto26HolXjSsZWcVj
XkEQiq46UAnss61O0Rp8eFTiN5MP9NlddLRrSoeJ4fXPTBUCAwEAAaOBwTCBvjAJ
BgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0
aWZpY2F0ZTAdBgNVHQ4EFgQU5bFe6DBFF8cohPvZ5ZOnMwiDfsAwHwYDVR0jBBgw
FoAUK9/vv3kTc8vk1DWlC+wYLGPk0vAwQwYDVR0RBDwwOoY4aHR0cDovL3dlYmlk
LmZjbnMuZXUvcGVvcGxlL3A1LWNnaS1hdXRoLWZvYWYtc3NsL2NhcmQjbWUwDQYJ
KoZIhvcNAQEFBQADgYEAVjpH54A2iTWNR24bNGrCfegsrPzuSvPXAk/GIAz3fK53
WJpJKNlEMTiXEGXfX0CFIJMNtwNXodSAxwU9xTSs6fSIe6m1cb5o8dnMAZ8bW3ss
HTRS2zGtz4CPPbA9Y4YYg/aP9NeLGw4dLcP+j5FhpkCkLMUVqDxKyBmcjkQVPz8=
-----END CERTIFICATE-----';

my $auth = CGI::Auth::FOAF_SSL->new($cert);
p $auth;

#print $auth->account->identity . "\n";
#print $auth->account->name . "\n";
#print $auth->account->homepage . "\n";

print $auth->agent->identity . "\n";
print $auth->agent->name . "\n";
print $auth->agent->homepage . "\n";
print $auth->agent->img . "\n";
print $auth->agent->mbox . "\n";

print ($auth->is_secure ? 'Secure' : 'NOT SECURE');
print "\n";
